==> haskell-show-combinators-0.2.0.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-show-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 show-combinators
version:              0.2.0.0
visibility:           public
id:                   show-combinators-0.2.0.0-8KsAGO0QJab9ULJLsn5bKj
key:                  show-combinators-0.2.0.0-8KsAGO0QJab9ULJLsn5bKj
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/show-combinators#readme
synopsis:             Combinators to write Show instances
description:
    A minimal pretty-printing library for Show instances in Haskell.

category:             Text
abi:                  9f8b15a2f35837454b6f99c399edab60
exposed:              True
exposed-modules:      Text.Show.Combinators
import-dirs:          /usr/lib/ghc-8.10.1/site-local/show-combinators-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/show-combinators-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/show-combinators-0.2.0.0
hs-libraries:         HSshow-combinators-0.2.0.0-8KsAGO0QJab9ULJLsn5bKj
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-show-combinators/html/show-combinators.haddock

haddock-html:         /usr/share/doc/haskell-show-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-show-combinators-0.2.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-show-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 show-combinators
version:              0.2.0.0
visibility:           public
id:                   show-combinators-0.2.0.0-Mu8Ya8yf9e8onG2PwsHE9
key:                  show-combinators-0.2.0.0-Mu8Ya8yf9e8onG2PwsHE9
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/show-combinators#readme
synopsis:             Combinators to write Show instances
description:
    A minimal pretty-printing library for Show instances in Haskell.

category:             Text
abi:                  18e85ffdf68d041d148ebdb35a9ed659
exposed:              True
exposed-modules:      Text.Show.Combinators
import-dirs:          /usr/lib/ghc-8.10.2/site-local/show-combinators-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/show-combinators-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/show-combinators-0.2.0.0
hs-libraries:         HSshow-combinators-0.2.0.0-Mu8Ya8yf9e8onG2PwsHE9
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-show-combinators/html/show-combinators.haddock

haddock-html:         /usr/share/doc/haskell-show-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
